@@ -46,6 +46,14 @@
 #define TABLE_PADDING 5
 
 
+/* Some defaults */
+
+#define DEFAULT_OUTPUT_VIDEO_FORMAT \
+    NV_CTRL_GVO_VIDEO_FORMAT_487I_59_94_SMPTE259_NTSC
+
+#define DEFAULT_OUTPUT_DATA_FORMAT \
+    NV_CTRL_GVO_DATA_FORMAT_R8G8B8_TO_YCRCB444
+
 
 /* General information help */
 
@@ -102,13 +110,13 @@ static void fill_output_video_format_menu(CtkGvo *ctk_gvo);
 static void trim_output_video_format_menu(CtkGvo *ctk_gvo);
 static void output_video_format_ui_changed(CtkDropDownMenu *menu,
                                            gpointer user_data);
-static void post_output_video_format_changed(CtkGvo *ctk_gvo, gint value);
+static void post_output_video_format_changed(CtkGvo *ctk_gvo);
 
 
-static void validate_output_data_format(CtkGvo *ctk_gvo, gint value);
+static void validate_output_data_format(CtkGvo *ctk_gvo);
 static void output_data_format_ui_changed(CtkDropDownMenu *menu,
                                           gpointer user_data);
-static void post_output_data_format_changed(CtkGvo *ctk_gvo, gint value);
+static void post_output_data_format_changed(CtkGvo *ctk_gvo);
 
 
 static void x_offset_ui_changed(GtkSpinButton *spinbutton, gpointer user_data);
@@ -235,6 +243,37 @@ static const GvoFormatName dataFormatNames[] = {
 
 /**** Utility Functions ******************************************************/
 
+
+/*
+ * get_first_available_output_video_format() - returns the first available
+ * output video format from the dropdown menu.  This is needed since when
+ * Frame Lock/Genlock are enabled, the default case of 487i may not be
+ * appropriate.
+ */
+
+static gint get_first_available_output_video_format(CtkGvo *ctk_gvo)
+{
+    CtkDropDownMenu *dmenu =
+        CTK_DROP_DOWN_MENU(ctk_gvo->output_video_format_menu);
+    int i;
+
+    /* look through the output video format dropdown for the first
+     * available selection.
+     */
+    for (i = 0; i < dmenu->num_entries; i++) {
+        if (GTK_WIDGET_IS_SENSITIVE(dmenu->values[i].menu_item)) {
+            return dmenu->values[i].value;
+        }
+    }
+
+    /* There are no available video formats?  Fallback to 487i. */
+
+    return NV_CTRL_GVO_VIDEO_FORMAT_487I_59_94_SMPTE259_NTSC;
+
+} /* get_first_available_output_video_format() */
+
+
+
 /*
  * ctk_gvo_get_video_format_name() - return the name of the given video format
  */
@@ -332,7 +371,8 @@ GType ctk_gvo_get_type(void)
 /*
  * trim_output_video_format_menu() - given the current
  * OUTPUT_VIDEO_FORMAT and SYNC_MODE, set the sensitivity of each menu
- * entry and possibly update which entry is current.
+ * entry and possibly update which of the output video mode dropdown
+ * entries is currently selected.
  */
 
 static void trim_output_video_format_menu(CtkGvo *ctk_gvo)
@@ -340,7 +380,7 @@ static void trim_output_video_format_menu(CtkGvo *ctk_gvo)
     ReturnStatus ret;
     NVCTRLAttributeValidValuesRec valid;
     gint bitmask, bitmask2, i, refresh_rate;
-    gboolean sensitive, current_not_available = FALSE;
+    gboolean sensitive, current_available;
 
     /* retrieve the currently available values */
 
@@ -441,6 +481,7 @@ static void trim_output_video_format_menu(CtkGvo *ctk_gvo)
      * bitmask, then it is available
      */
 
+    current_available = FALSE;
     for (i = 0; videoFormatNames[i].name; i++) {
         if (((videoFormatNames[i].format < 32) &&
              ((1 << videoFormatNames[i].format) & bitmask)) ||
@@ -458,8 +499,8 @@ static void trim_output_video_format_menu(CtkGvo *ctk_gvo)
         /* if the current video is not sensitive, take note */
         
         if ((ctk_gvo->output_video_format == videoFormatNames[i].format) &&
-            !sensitive) {
-            current_not_available = TRUE;
+            sensitive) {
+            current_available = TRUE;
         }
     }
     
@@ -468,23 +509,32 @@ static void trim_output_video_format_menu(CtkGvo *ctk_gvo)
      * available format current
      */
     
-    if (current_not_available && bitmask) {
+    if (!current_available && bitmask) {
+
         for (i = 0; videoFormatNames[i].name; i++) {
             if (((videoFormatNames[i].format < 32) &&
                  ((1 << videoFormatNames[i].format) & bitmask)) ||
                 ((videoFormatNames[i].format >= 32) &&
                  ((1 << (videoFormatNames[i].format - 32)) & bitmask2))) {
                 
-                NvCtrlSetAttribute(ctk_gvo->handle,
-                                   NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT,
-                                   videoFormatNames[i].format);
-                
+                /* Invalidate the format so it gets set when clone mode is
+                 * enabled.
+                 */
+                ctk_gvo->output_video_format_valid = FALSE;
+
+                g_signal_handlers_block_by_func
+                    (G_OBJECT(ctk_gvo->output_video_format_menu),
+                     G_CALLBACK(output_video_format_ui_changed),
+                     (gpointer) ctk_gvo);
+
                 ctk_drop_down_menu_set_current_value
                     (CTK_DROP_DOWN_MENU(ctk_gvo->output_video_format_menu),
                      videoFormatNames[i].format);
-                
-                ctk_gvo->output_video_format = videoFormatNames[i].format;
 
+                g_signal_handlers_unblock_by_func
+                    (G_OBJECT(ctk_gvo->output_video_format_menu),
+                     G_CALLBACK(output_video_format_ui_changed),
+                     (gpointer) ctk_gvo);
                 break;
             }
         }
@@ -512,15 +562,15 @@ static void trim_output_video_format_menu(CtkGvo *ctk_gvo)
  *       be enabled while calling this function.
  */
 
-static void validate_output_video_format(CtkGvo *ctk_gvo, gint format)
+static void validate_output_video_format(CtkGvo *ctk_gvo)
 {
     gint bitmask, bitmask2;
     gint width, height;
+    gint format = ctk_gvo->output_video_format;
 
     /* Keep track of whether we'll need to re-set the video format
      * when enabling clone mode.
      */
-    ctk_gvo->output_video_format_invalid = TRUE;
 
     /* Check to make sure the format size <= current screen size */
     ctk_gvo_get_video_format_resolution(format, &width, &height);
@@ -529,6 +579,7 @@ static void validate_output_video_format(CtkGvo *ctk_gvo, gint format)
     if ((width > ctk_gvo->screen_width) ||
         (height > ctk_gvo->screen_height)) {
         /* Format is invalid due to screen size limitations */
+        ctk_gvo->output_video_format_valid = FALSE;
         return;
     }
 
@@ -539,12 +590,12 @@ static void validate_output_video_format(CtkGvo *ctk_gvo, gint format)
     if (((format < 32) && !((1 << format) & bitmask)) ||
         ((format >= 32) && !((1 << (format - 32)) & bitmask2))) {
         /* Format is invalid due to genlock/framelock requirements */
+        ctk_gvo->output_video_format_valid = FALSE;
         return;
     }
 
     /* If we got this far, then the format is valid. */
-    ctk_gvo->output_video_format = format;
-    ctk_gvo->output_video_format_invalid = FALSE;
+    ctk_gvo->output_video_format_valid = TRUE;
 
 } /* validate_output_video_format() */
 
@@ -561,23 +612,23 @@ static void validate_output_video_format(CtkGvo *ctk_gvo, gint format)
  *       be enabled while calling this function.
  */
 
-static void validate_output_data_format(CtkGvo *ctk_gvo, gint format)
+static void validate_output_data_format(CtkGvo *ctk_gvo)
 {
     int i;
 
     /* Keep track of whether we'll need to re-set the data format
      * when enabling clone mode.
      */
-    ctk_gvo->output_data_format_invalid = TRUE;
     for (i = 0; dataFormatNames[i].name; i++) {
-        if (format == dataFormatNames[i].format) {
+        if (ctk_gvo->output_data_format == dataFormatNames[i].format) {
             /* Value is OK */
-            ctk_gvo->output_data_format = format;
-            ctk_gvo->output_data_format_invalid = FALSE;
-            break;
+            ctk_gvo->output_data_format_valid = TRUE;
+            return;
         }
     }
 
+    ctk_gvo->output_data_format_valid = FALSE;
+
 } /* validate_output_data_format() */
 
 
@@ -727,19 +778,17 @@ GtkWidget* ctk_gvo_new(NvCtrlAttributeHandle *handle,
 
     finish_menu(menu, table, 0);
     
-    trim_output_video_format_menu(ctk_gvo);
+    /* Make sure that the video format selected is valid for clone mode */
 
-    /* Make sure that the video format selected is valid */
-
-    validate_output_video_format(ctk_gvo, ctk_gvo->output_video_format);
-    if (ctk_gvo->output_video_format_invalid) {
-        ctk_gvo->output_video_format =
-            NV_CTRL_GVO_VIDEO_FORMAT_487I_59_94_SMPTE259_NTSC;
+    validate_output_video_format(ctk_gvo);
+    if (ctk_gvo->output_video_format_valid) {
+        val = ctk_gvo->output_video_format;
+    } else {
+        val = get_first_available_output_video_format(ctk_gvo);
     }
 
     ctk_drop_down_menu_set_current_value
-        (CTK_DROP_DOWN_MENU(ctk_gvo->output_video_format_menu),
-         ctk_gvo->output_video_format);
+        (CTK_DROP_DOWN_MENU(ctk_gvo->output_video_format_menu), val);
 
     g_signal_connect(G_OBJECT(ctk_gvo->output_video_format_menu),
                      "changed", G_CALLBACK(output_video_format_ui_changed),
@@ -748,6 +797,9 @@ GtkWidget* ctk_gvo_new(NvCtrlAttributeHandle *handle,
     /* Output Data Format */
     
     menu = start_menu("Data Format: ", table, 1);
+    ctk_gvo->output_data_format_menu = menu;
+    ctk_config_set_tooltip(ctk_config, CTK_DROP_DOWN_MENU(menu)->option_menu,
+                           __clone_mode_data_format_help);
     
     for (i = 0; dataFormatNames[i].name; i++) {
         ctk_drop_down_menu_append_item(CTK_DROP_DOWN_MENU(menu),
@@ -756,22 +808,18 @@ GtkWidget* ctk_gvo_new(NvCtrlAttributeHandle *handle,
     }
     
     finish_menu(menu, table, 1);
-    
-    ctk_gvo->output_data_format_menu = menu;
-    ctk_config_set_tooltip(ctk_config, CTK_DROP_DOWN_MENU(menu)->option_menu,
-                           __clone_mode_data_format_help);
 
-    /* Make sure that the data format selected is valid */
+    /* Make sure that the data format selected is valid for clone mode */
 
-    validate_output_data_format(ctk_gvo, ctk_gvo->output_data_format);
-    if (ctk_gvo->output_data_format_invalid) {
-        ctk_gvo->output_data_format =
-            NV_CTRL_GVO_DATA_FORMAT_R8G8B8_TO_YCRCB444;
+    validate_output_data_format(ctk_gvo);
+    if (ctk_gvo->output_data_format_valid) {
+        val = ctk_gvo->output_data_format;
+    } else {
+        val = DEFAULT_OUTPUT_DATA_FORMAT;
     }
     
     ctk_drop_down_menu_set_current_value
-        (CTK_DROP_DOWN_MENU(ctk_gvo->output_data_format_menu),
-         ctk_gvo->output_data_format);
+        (CTK_DROP_DOWN_MENU(ctk_gvo->output_data_format_menu), val);
 
     g_signal_connect(G_OBJECT(ctk_gvo->output_data_format_menu),
                      "changed", G_CALLBACK(output_data_format_ui_changed),
@@ -1061,7 +1109,7 @@ static void fill_output_video_format_menu(CtkGvo *ctk_gvo)
             return;
         }
         
-        /* check that the current X screen can support width and height */
+        /* check that the current X screen can support the width and height */
         
         width = videoFormatDetails[i].width;
         height = videoFormatDetails[i].height;
@@ -1092,6 +1140,9 @@ static void fill_output_video_format_menu(CtkGvo *ctk_gvo)
              0);
     }
 
+    /* Trim output video format based on sync mode */
+    trim_output_video_format_menu(ctk_gvo);
+
 } /* fill_output_video_format_menu() */
 
 
@@ -1149,7 +1200,7 @@ static gboolean query_init_gvo_state(CtkGvo *ctk_gvo)
     ret = NvCtrlGetAttribute(ctk_gvo->handle, NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT,
                              &val);
     if (ret != NvCtrlSuccess) {
-        val = NV_CTRL_GVO_VIDEO_FORMAT_487I_59_94_SMPTE259_NTSC;
+        val = DEFAULT_OUTPUT_VIDEO_FORMAT;
     }
     ctk_gvo->output_video_format = val;
 
@@ -1157,7 +1208,7 @@ static gboolean query_init_gvo_state(CtkGvo *ctk_gvo)
 
     ret = NvCtrlGetAttribute(ctk_gvo->handle, NV_CTRL_GVO_DATA_FORMAT, &val);
     if (ret != NvCtrlSuccess) {
-        val = NV_CTRL_GVO_DATA_FORMAT_R8G8B8_TO_YCRCB444;
+        val = DEFAULT_OUTPUT_DATA_FORMAT;
     }
     ctk_gvo->output_data_format = val;
 
@@ -1273,24 +1324,15 @@ static void output_video_format_ui_changed(CtkDropDownMenu *menu,
                                            gpointer user_data)
 {
     CtkGvo *ctk_gvo = CTK_GVO(user_data);
-    gint value;
-    
-    value = ctk_drop_down_menu_get_current_value(menu);
-    
-    if (((value < 32) &&
-         !(ctk_gvo->valid_output_video_format_mask[0] & (1 << value))) ||
-        ((value >= 32) &&
-         !(ctk_gvo->valid_output_video_format_mask[1] & (1 << (value - 32))))){
-        
-        ctk_config_statusbar_message(ctk_gvo->ctk_config, "Invalid "
-                                     "Output Video Format: %s; ignoring.",
-                                     ctk_gvo_get_video_format_name(value));
-    } else {
-        NvCtrlSetAttribute(ctk_gvo->handle,
-                           NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT, value);
-    }
 
-    post_output_video_format_changed(ctk_gvo, value);
+    ctk_gvo->output_video_format = ctk_drop_down_menu_get_current_value(menu);
+    ctk_gvo->output_video_format_valid = TRUE;
+
+    NvCtrlSetAttribute(ctk_gvo->handle,
+                       NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT,
+                       ctk_gvo->output_video_format);
+
+    post_output_video_format_changed(ctk_gvo);
     
 } /* output_video_format_ui_changed() */
 
@@ -1305,13 +1347,14 @@ static void output_data_format_ui_changed(CtkDropDownMenu *menu,
                                           gpointer user_data)
 {
     CtkGvo *ctk_gvo = CTK_GVO(user_data);
-    gint value;
     
-    value = ctk_drop_down_menu_get_current_value(menu);
+    ctk_gvo->output_data_format = ctk_drop_down_menu_get_current_value(menu);
+    ctk_gvo->output_data_format_valid = TRUE;
     
-    NvCtrlSetAttribute(ctk_gvo->handle, NV_CTRL_GVO_DATA_FORMAT, value);
+    NvCtrlSetAttribute(ctk_gvo->handle, NV_CTRL_GVO_DATA_FORMAT,
+                       ctk_gvo->output_data_format);
     
-    post_output_data_format_changed(ctk_gvo, value);
+    post_output_data_format_changed(ctk_gvo);
     
 } /* output_data_format_ui_changed() */
 
@@ -1367,9 +1410,6 @@ static void clone_mode_button_ui_toggled(GtkWidget *button, gpointer user_data)
 
     enabled = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
     
-    if (enabled) val = NV_CTRL_GVO_DISPLAY_X_SCREEN_ENABLE;
-    else         val = NV_CTRL_GVO_DISPLAY_X_SCREEN_DISABLE;
-
 
     /*
      * When enabling clone mode, we must make sure that the output
@@ -1378,26 +1418,28 @@ static void clone_mode_button_ui_toggled(GtkWidget *button, gpointer user_data)
      */
 
     if (enabled) {
-        if (ctk_gvo->output_video_format_invalid) {
+        if (!ctk_gvo->output_video_format_valid) {
+            val = ctk_drop_down_menu_get_current_value
+                (CTK_DROP_DOWN_MENU(ctk_gvo->output_video_format_menu));
+            ctk_gvo->output_video_format = val;
+            ctk_gvo->output_video_format_valid = TRUE;
             NvCtrlSetAttribute(ctk_gvo->handle,
                                NV_CTRL_GVO_OUTPUT_VIDEO_FORMAT,
                                ctk_gvo->output_video_format);
-
-            ctk_drop_down_menu_set_current_value
-                (CTK_DROP_DOWN_MENU(ctk_gvo->output_video_format_menu),
-                 ctk_gvo->output_video_format);
         }
-        if (ctk_gvo->output_data_format_invalid) {
+        if (!ctk_gvo->output_data_format_valid) {
+            val = ctk_drop_down_menu_get_current_value
+                (CTK_DROP_DOWN_MENU(ctk_gvo->output_data_format_menu));
+            ctk_gvo->output_data_format = val;
+            ctk_gvo->output_data_format_valid = TRUE;
             NvCtrlSetAttribute(ctk_gvo->handle,
                                NV_CTRL_GVO_DATA_FORMAT,
-                               ctk_gvo->output_data_format);
-
-            ctk_drop_down_menu_set_current_value
-                (CTK_DROP_DOWN_MENU(ctk_gvo->output_data_format_menu),
-                 ctk_gvo->output_data_format);
+                               val);
         }
     }
 
+    if (enabled) val = NV_CTRL_GVO_DISPLAY_X_SCREEN_ENABLE;
+    else         val = NV_CTRL_GVO_DISPLAY_X_SCREEN_DISABLE;
     NvCtrlSetAttribute(ctk_gvo->handle, NV_CTRL_GVO_DISPLAY_X_SCREEN, val);
     
     /*
@@ -1448,10 +1490,8 @@ static void clone_mode_button_ui_toggled(GtkWidget *button, gpointer user_data)
  *
  */
 
-static void post_output_video_format_changed(CtkGvo *ctk_gvo, gint value)
+static void post_output_video_format_changed(CtkGvo *ctk_gvo)
 {
-    validate_output_video_format(ctk_gvo, value);
-
     /* Update UI state */
 
     update_gvo_current_info(ctk_gvo);
@@ -1460,7 +1500,8 @@ static void post_output_video_format_changed(CtkGvo *ctk_gvo, gint value)
     
     ctk_config_statusbar_message(ctk_gvo->ctk_config,
                                  "Output Video Format set to: %s.",
-                                 ctk_gvo_get_video_format_name(value));
+                                 ctk_gvo_get_video_format_name
+                                 (ctk_gvo->output_video_format));
 
 } /* post_output_video_format_changed() */
 
@@ -1472,13 +1513,12 @@ static void post_output_video_format_changed(CtkGvo *ctk_gvo, gint value)
  * or through an NV-CONTROL event.
  */
 
-static void post_output_data_format_changed(CtkGvo *ctk_gvo, gint value)
+static void post_output_data_format_changed(CtkGvo *ctk_gvo)
 {
-    validate_output_data_format(ctk_gvo, value);
-
-    ctk_config_statusbar_message(ctk_gvo->ctk_config,
-                                 "Output Data Format set to: %s.",
-                                 ctk_gvo_get_data_format_name(value));
+    ctk_config_statusbar_message
+        (ctk_gvo->ctk_config,
+         "Output Data Format set to: %s.",
+         ctk_gvo_get_data_format_name(ctk_gvo->output_data_format));
 
 } /* post_output_data_format_changed() */
 
@@ -1680,12 +1720,17 @@ static void gvo_event_received(GtkObject *object,
              G_CALLBACK(output_video_format_ui_changed),
              (gpointer) ctk_gvo);
         
-        if (!ctk_gvo->output_video_format_invalid) {
-            ctk_drop_down_menu_set_current_value
-                (CTK_DROP_DOWN_MENU(widget), value);
+        ctk_gvo->output_video_format = value;
+        validate_output_video_format(ctk_gvo);
+       
+        /* Update the dropdown with a reasonable value */
+        if (!ctk_gvo->output_video_format_valid) {
+            value = get_first_available_output_video_format(ctk_gvo);
         }
-        
-        post_output_video_format_changed(ctk_gvo, value);
+        ctk_drop_down_menu_set_current_value
+            (CTK_DROP_DOWN_MENU(widget), value);
+
+        post_output_video_format_changed(ctk_gvo);
 
         g_signal_handlers_unblock_by_func
             (G_OBJECT(widget),
@@ -1701,13 +1746,17 @@ static void gvo_event_received(GtkObject *object,
              G_CALLBACK(output_data_format_ui_changed),
              (gpointer) ctk_gvo);
 
-
-        if (!ctk_gvo->output_data_format_invalid) {
-            ctk_drop_down_menu_set_current_value
-                (CTK_DROP_DOWN_MENU(widget), value);
+        ctk_gvo->output_data_format = value;
+        validate_output_data_format(ctk_gvo);
+       
+        /* Update the dropdown with a reasonable value */
+        if (!ctk_gvo->output_data_format_valid) {
+            value = DEFAULT_OUTPUT_DATA_FORMAT;
         }
+        ctk_drop_down_menu_set_current_value
+            (CTK_DROP_DOWN_MENU(widget), value);
 
-        post_output_data_format_changed(ctk_gvo, value);
+        post_output_data_format_changed(ctk_gvo);
 
         g_signal_handlers_unblock_by_func
             (G_OBJECT(widget),
@@ -1778,7 +1827,7 @@ static void screen_changed_handler(GtkWidget *widget,
 {
     CtkGvo *ctk_gvo = CTK_GVO(data);
     CtkDropDownMenu *dmenu;
-    gint idx;
+    gint val;
 
     /* Cache the new screen dimensions */
 
@@ -1789,9 +1838,10 @@ static void screen_changed_handler(GtkWidget *widget,
 
     dmenu = CTK_DROP_DOWN_MENU(ctk_gvo->output_video_format_menu);
 
-    /* Get the currently selected index */
+    /* Get the currently selected value */
 
-    idx = gtk_option_menu_get_history(GTK_OPTION_MENU(dmenu->option_menu));
+    val = ctk_drop_down_menu_get_current_value
+        (CTK_DROP_DOWN_MENU(ctk_gvo->output_video_format_menu));
 
     /* Reset the drop down menu */
 
@@ -1803,27 +1853,25 @@ static void screen_changed_handler(GtkWidget *widget,
 
     /* Finalize and load the menu */
 
-    ctk_drop_down_menu_finalize(dmenu);
-    
-    /* Set the old value if possible.  Note that it is OK to just
-     * care about the selected index because the modes are sorted
-     * by size.
-     */
-
-    validate_output_video_format(ctk_gvo, idx);
-    if (ctk_gvo->output_video_format_invalid) {
-        ctk_gvo->output_video_format =
-            NV_CTRL_GVO_VIDEO_FORMAT_487I_59_94_SMPTE259_NTSC;
-    }
-
     g_signal_handlers_block_by_func
         (G_OBJECT(ctk_gvo->output_video_format_menu),
          G_CALLBACK(output_video_format_ui_changed),
          (gpointer) ctk_gvo);
+
+    ctk_drop_down_menu_finalize(dmenu);
     
+    /* Set best valid output video format value possible.
+     * Revalidate here since the screen change could cause
+     * the current output video mode to now be valid.
+     */
+    
+    validate_output_video_format(ctk_gvo);
+    if (ctk_gvo->output_video_format_valid) {
+        val = ctk_gvo->output_video_format;
+    }
+
     ctk_drop_down_menu_set_current_value
-        (CTK_DROP_DOWN_MENU(ctk_gvo->output_video_format_menu),
-         ctk_gvo->output_video_format);
+        (CTK_DROP_DOWN_MENU(ctk_gvo->output_video_format_menu), val);
 
     g_signal_handlers_unblock_by_func
         (G_OBJECT(ctk_gvo->output_video_format_menu),
@@ -1861,15 +1909,20 @@ static void screen_changed_handler(GtkWidget *widget,
 gint ctk_gvo_probe_callback(gpointer data)
 {
     CtkGvo *ctk_gvo = CTK_GVO(data);
-    gint old_format = ctk_gvo->input_video_format;
+    gint old_input_format = ctk_gvo->input_video_format;
+    gint old_sync_mode = ctk_gvo->sync_mode;
 
     /* Update our copies of some SDI state variables */
 
     ctk_gvo->input_video_format =
         CTK_GVO_BANNER(ctk_gvo->banner)->input_video_format;
 
-    if ((old_format != ctk_gvo->input_video_format)  &&
-        (ctk_gvo->lock_owner == NV_CTRL_GVO_LOCK_OWNER_NONE)) {
+    ctk_gvo->sync_mode =
+        CTK_GVO_BANNER(ctk_gvo->banner)->sync_mode;
+
+    if ((ctk_gvo->lock_owner == NV_CTRL_GVO_LOCK_OWNER_NONE) &&
+        ((old_input_format != ctk_gvo->input_video_format) ||
+         (old_sync_mode != ctk_gvo->sync_mode))) {
         
         /* update the available output video formats */
         
